﻿using Microsoft.Win32;
using Syncfusion.Data;
using Syncfusion.UI.Xaml.Grid;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace SfDataGridSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        string FilterValue = "";
        public MainWindow()
        {
            InitializeComponent();
            this.datagrid.Loaded += datagrid_Loaded;
            this.datagrid.ItemsSourceChanged += datagrid_ItemsSourceChanged;
            this.datagrid.FilterChanging += datagrid_FilterChanging;
            this.datagrid.FilterChanged+=datagrid_FilterChanged;
            this.datagrid.FilterItemsPopulated += datagrid_FilterItemsPopulated;
            this.datagrid.SerializationController = new SerializationControllerExt(this.datagrid);
         
        }

        void datagrid_FilterItemsPopulated(object sender, GridFilterItemsPopulatedEventArgs e)
        {
            filterItems = e.ItemsSource as IEnumerable<FilterElement>;
            e.FilterControl.FilterMode = FilterMode.CheckboxFilter;
            //throw new NotImplementedException();
        }
        IEnumerable<FilterElement> filterItems;
        void datagrid_FilterChanging(object sender, Syncfusion.UI.Xaml.Grid.GridFilterEventArgs e)
        {
            if (e.FilterPredicates == null || filterItems == null || !e.FilterPredicates.Any() || !filterItems.Any())
                return;

            e.FilterPredicates.Clear();
            var selectedItems = filterItems.Where(x => x.IsSelected);
            int i = 0;
            foreach (var item in selectedItems)
            {
                if (i == 0)
                    e.FilterPredicates.Add(new FilterPredicate()
                    {
                        FilterValue = item.ActualValue,
                        FilterType = FilterType.Equals,
                        FilterBehavior = FilterBehavior.StronglyTyped,
                        IsCaseSensitive = true,
                        PredicateType = PredicateType.And
                    });
                else
                {
                    e.FilterPredicates.Add(new FilterPredicate()
                    {
                        FilterValue = item.ActualValue,
                        FilterType = FilterType.Equals,
                        FilterBehavior = FilterBehavior.StronglyTyped,
                        IsCaseSensitive = true,
                        PredicateType = PredicateType.Or
                    });

                }
                i++;
            }
            //throw new NotImplementedException();
        }

        void datagrid_ItemsSourceChanged(object sender, Syncfusion.UI.Xaml.Grid.GridItemsSourceChangedEventArgs e)
        {
            this.datagrid.Columns["EmployeeArea"].FilterPredicates.Add(new Syncfusion.Data.FilterPredicate()
            {
                FilterBehavior = Syncfusion.Data.FilterBehavior.StronglyTyped,
                FilterType = Syncfusion.Data.FilterType.Equals,
                FilterValue = "USA",
            });
        }
        void datagrid_Loaded(object sender, RoutedEventArgs e)
        {
           /*if(this.datagrid.Columns["EmployeeArea"].FilterPredicates.Count >0)
           {
               this.Title = this.datagrid.Columns["EmployeeArea"].FilterPredicates[0].FilterValue.ToString();
           }*/
           DisplayFilterValue();
        }

        private void DisplayFilterValue()
        {
            
            if (datagrid.Columns["EmployeeArea"].FilterPredicates.Count > 0)
            {
                foreach (var filter in datagrid.Columns["EmployeeArea"].FilterPredicates)
                {
                    FilterValue += filter.FilterValue.ToString() + " ";
                }
                FilterValue = FilterValue.Trim();
            }

            if (FilterValue.Length == 0)
            {
                Grid_Filter.Height = new GridLength(0);
                FilterValue = "";
            }
            else
            {
                Grid_Filter.Height = new GridLength(25);
                tStatus.Content = "Filter: " + FilterValue;
            }
        }

        private void datagrid_FilterChanged(object sender, Syncfusion.UI.Xaml.Grid.GridFilterEventArgs e)
        {
            FilterValue = "";
            DisplayFilterValue();
           
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            if (datagrid == null) return;
            var options = new SerializationOptions();
            try
            {
                using (var file = File.Create("DataGrid.xml"))
                {
                    datagrid.Serialize(file, options);
                }
            }
            catch (Exception)
            {

            }

        }

        private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            if (datagrid == null) return;
            var options = new DeserializationOptions();
            try
            {
                using (var file = File.Open("DataGrid.xml", FileMode.Open))
                {
                    datagrid.Deserialize(file, options);
                }
            }
            catch (Exception)
            {

            }
        }
       
    }
}
